==> bs-platform-5.0.0-dev.5.tgz: package/jscomp/others/js_exn.mli <==
(* Copyright (C) 2015-2016 Bloomberg Finance L.P.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * In addition to the permissions granted to you by the LGPL, you may combine
 * or link a "work that uses the Library" with a publicly distributed version
 * of this file to produce a combined library or application, then distribute
 * that combined work under the terms of your choosing, with no requirement
 * to comply with the obligations normally placed on you by section 4 of the
 * LGPL version 3 (or the corresponding section of a later version of the LGPL
 * should you choose to use a later version).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *)

type t 

type exn += private Error of t 

external asJsExn : exn -> t option = 
  "caml_as_js_exn"

external stack : t -> string option = ""
  [@@bs.get] 
external message : t -> string option = ""
  [@@bs.get] 
external name : t -> string option = ""
  [@@bs.get] 
external fileName : t -> string option = ""
  [@@bs.get] 


external isCamlExceptionOrOpenVariant:
  'a -> bool = "caml_is_extension"
(** internal use only *)


(** Raise Js exception Error object with stacktrace *)
val raiseError : string -> 'a
val raiseEvalError : string -> 'a
val raiseRangeError : string -> 'a
val raiseReferenceError :  string -> 'a
val raiseSyntaxError : string -> 'a
val raiseTypeError : string -> 'a
val raiseUriError :  string -> 'a

==> bs-platform-5.1.0.tgz: package/jscomp/others/js_exn.mli <==
(* Copyright (C) 2015-2016 Bloomberg Finance L.P.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * In addition to the permissions granted to you by the LGPL, you may combine
 * or link a "work that uses the Library" with a publicly distributed version
 * of this file to produce a combined library or application, then distribute
 * that combined work under the terms of your choosing, with no requirement
 * to comply with the obligations normally placed on you by section 4 of the
 * LGPL version 3 (or the corresponding section of a later version of the LGPL
 * should you choose to use a later version).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *)

type t 

type exn += private Error of t 

external asJsExn : exn -> t option = 
  "caml_as_js_exn"

external stack : t -> string option = "stack"
  [@@bs.get] 
external message : t -> string option = "message"
  [@@bs.get] 
external name : t -> string option = "name"
  [@@bs.get] 
external fileName : t -> string option = "fileName"
  [@@bs.get] 


external isCamlExceptionOrOpenVariant:
  'a -> bool = "caml_is_extension"
(** internal use only *)


(** Raise Js exception Error object with stacktrace *)
val raiseError : string -> 'a
val raiseEvalError : string -> 'a
val raiseRangeError : string -> 'a
val raiseReferenceError :  string -> 'a
val raiseSyntaxError : string -> 'a
val raiseTypeError : string -> 'a
val raiseUriError :  string -> 'a
